@@ -61,7 +61,7 @@ class FFile:
 		"""Aggiungi alla fine del file il contenuto"""
 		if self.__file_exists():
 			self.read_json()
-			list(self.json_['to_key']).append(content)
+			list(self.json_[to_key]).append(content)
 			with open(self.nomeFile, "a") as fa:
 				fa.write(self.json_)
 		else:
